@@ -64,16 +64,16 @@ class QuerySetSingle(Protocol[T_co]):
     def __await__(self) -> Generator[Any, None, T_co]:
         ...  # pragma: nocoverage
 
-    def prefetch_related(self, *args: Union[str, Prefetch]) -> "QuerySetSingle[MODEL]":
+    def prefetch_related(self, *args: Union[str, Prefetch]) -> "QuerySetSingle[T_co]":
         ...  # pragma: nocoverage
 
-    def select_related(self, *args: str) -> "QuerySetSingle[MODEL]":
+    def select_related(self, *args: str) -> "QuerySetSingle[T_co]":
         ...  # pragma: nocoverage
 
-    def annotate(self, **kwargs: Function) -> "QuerySetSingle[MODEL]":
+    def annotate(self, **kwargs: Function) -> "QuerySetSingle[T_co]":
         ...  # pragma: nocoverage
 
-    def only(self, *fields_for_select: str) -> "QuerySetSingle[MODEL]":
+    def only(self, *fields_for_select: str) -> "QuerySetSingle[T_co]":
         ...  # pragma: nocoverage
 
     def values_list(self, *fields_: str, flat: bool = False) -> "ValuesListQuery":
@@ -142,7 +142,7 @@ class AwaitableQuery(Generic[MODEL]):
 
         if has_aggregate and (self._joined_tables or having_criterion or self.query._orderbys):
             self.query = self.query.groupby(
-                self.model._meta.basetable[self.model._meta.db_pk_column]
+                *[self.model._meta.basetable[field] for field in self.model._meta.db_fields]
             )
 
     def _join_table_by_field(
